@@ -5,7 +5,7 @@
 ;; Author: Daniel Mendler <mail@daniel-mendler.de>
 ;; Maintainer: Daniel Mendler <mail@daniel-mendler.de>
 ;; Created: 2023
-;; Version: 2.1
+;; Version: 2.2
 ;; Package-Requires: ((emacs "28.1") (compat "30"))
 ;; URL: https://github.com/minad/jinx
 ;; Keywords: convenience, text
@@ -288,8 +288,10 @@ Predicate may return a position to skip forward.")
 (defvar jinx--timer (timer-create)
   "Global timer to check pending regions.")
 
-(defvar jinx--base-syntax-table
+(defvar jinx--syntax-table
   (let ((st (make-syntax-table)))
+    (modify-syntax-entry ?' "w" st)
+    (modify-syntax-entry ?’ "w" st)
     (modify-syntax-entry ?$ "_" st)
     (modify-syntax-entry ?% "_" st)
     (modify-syntax-entry '(#xe000 . #xf8ff) "_" st)    ;; Priv. use area
@@ -301,13 +303,7 @@ Predicate may return a position to skip forward.")
     (modify-syntax-entry '(#x1cf00 . #x1d7ff) "_" st)  ;; Znamenny Musical - Math. Alpha.
     (modify-syntax-entry '(#x1ee00 . #x1fbff) "_" st)  ;; Arabic Math. - Legacy Computing
     st)
-  "Parent syntax table of `jinx--syntax-table'.")
-
-(defvar jinx--syntax-overrides
-  '((?' . "w")
-    (?’ . "w")
-    (?. . "."))
-  "Syntax table overrides used for `jinx--syntax-table'.")
+  "Syntax table used during checking.")
 
 (defvar jinx--select-keys
   "123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ"
@@ -338,12 +334,6 @@ Predicate may return a position to skip forward.")
 (defvar jinx--dicts-hash (make-hash-table :test #'equal :weakness 'value)
   "Weak hash table of all loaded dictionaries.")
 
-(defvar-local jinx--syntax-table nil
-  "Syntax table used during checking.
-The table inherits from `jinx--base-syntax-table'.  The table is
-configured according to the word characters defined by the local
-dictionaries.  Afterwards `jinx--syntax-overrides' are applied.")
-
 (defvar-local jinx--session-words nil
   "List of words accepted in this session.")
 
@@ -351,13 +341,12 @@ dictionaries.  Afterwards `jinx--syntax-overrides' are applied.")
 
 (defvar repeat-mode)
 (defvar jinx-mode)
-(declare-function jinx--mod-check nil)
-(declare-function jinx--mod-add nil)
-(declare-function jinx--mod-suggest nil)
-(declare-function jinx--mod-dict nil)
-(declare-function jinx--mod-describe nil)
-(declare-function jinx--mod-langs nil)
-(declare-function jinx--mod-wordchars nil)
+(declare-function jinx--mod-check "ext:jinx-mod.c")
+(declare-function jinx--mod-add "ext:jinx-mod.c")
+(declare-function jinx--mod-suggest "ext:jinx-mod.c")
+(declare-function jinx--mod-dict "ext:jinx-mod.c")
+(declare-function jinx--mod-describe "ext:jinx-mod.c")
+(declare-function jinx--mod-langs "ext:jinx-mod.c")
 
 ;;;; Overlay properties
 
@@ -532,8 +521,8 @@ If CHECK is non-nil, always check first."
         (with-delayed-message (1 "Checking...")
           (jinx--check-region start end))
         (jinx--get-overlays start end visible))
-      (user-error (if visible "No misspelled word in visible text"
-                    "No misspelled word in whole buffer"))))
+      (user-error "No misspelled word in %s"
+                  (if visible "visible text" (format "buffer `%s'" (buffer-name))))))
 
 (defun jinx--delete-overlays (start end)
   "Delete overlays between START and END."
@@ -642,7 +631,7 @@ If CHECK is non-nil, always check first."
   "Guard BODY during correction loop."
   `(cl-letf (((symbol-function #'jinx--timer-handler) #'ignore) ;; Inhibit
              (repeat-mode nil)) ;; No repeating of jinx-next and jinx-previous
-     (unless jinx-mode (jinx-mode 1))
+     (unless jinx-mode (jinx-mode))
      ,@body))
 
 (defun jinx--invisible-open-temporarily ()
@@ -867,20 +856,14 @@ Optionally show prompt INFO and insert INITIAL input."
 
 (defun jinx--load-dicts ()
   "Load dictionaries and setup syntax table."
-  (setq jinx--dicts (cl-loop for lang in (split-string jinx-languages)
-                             ;; Keep a weak reference to loaded dictionaries.
-                             ;; See <gh:rrthomas/enchant#402>.
-                             for dict = (with-memoization (gethash lang jinx--dicts-hash)
-                                          (jinx--mod-dict lang))
-                             if dict collect dict)
-        jinx--syntax-table (make-syntax-table jinx--base-syntax-table))
-  (unless jinx--dicts
-    (message "Jinx: No dictionaries available for %S" jinx-languages))
-  (dolist (dict jinx--dicts)
-    (cl-loop for c across (jinx--mod-wordchars dict) do
-             (modify-syntax-entry c "w" jinx--syntax-table)))
-  (cl-loop for (k . v) in jinx--syntax-overrides do
-           (modify-syntax-entry k v jinx--syntax-table)))
+  (unless (setq jinx--dicts
+                (cl-loop for lang in (split-string jinx-languages)
+                         ;; Keep a weak reference to loaded dictionaries.
+                         ;; See <gh:rrthomas/enchant#402>.
+                         for dict = (with-memoization (gethash lang jinx--dicts-hash)
+                                      (jinx--mod-dict lang))
+                         if dict collect dict))
+    (message "Jinx: No dictionaries available for %S" jinx-languages)))
 
 (defun jinx--bounds-of-word ()
   "Return bounds of word at point using `jinx--syntax-table'."
@@ -957,7 +940,8 @@ action KEY."
                      (declare-function project-root "project")
                      (project-root proj))
                    default-directory)))
-          (add-dir-local-variable nil 'jinx-dir-local-words jinx-dir-local-words)))
+          (save-window-excursion
+            (add-dir-local-variable nil 'jinx-dir-local-words jinx-dir-local-words))))
     (list key word "Directory")))
 
 (defun jinx--save-session (save key word)
@@ -978,7 +962,7 @@ read via `completing-read-multiple'.  If the prefix argument
 GLOBAL is non-nil, the languages are changed globally for all
 buffers.  See also the variable `jinx-languages'."
   (interactive (list (jinx--read-languages) current-prefix-arg))
-  (unless jinx-mode (jinx-mode 1))
+  (unless jinx-mode (jinx-mode))
   (cond
    (global
     (kill-local-variable 'jinx-languages)
@@ -999,7 +983,7 @@ buffers.  See also the variable `jinx-languages'."
 (defun jinx-correct-all (&optional only-check)
   "Correct all misspelled words in the buffer.
 With prefix argument ONLY-CHECK, only check the buffer and highlight all
-misspellings, but do not open the correction UI."
+misspelled words, but do not open the correction UI."
   (interactive "*P")
   (jinx--correct-guard
    (let* ((overlays (jinx--force-overlays (or (use-region-beginning) (point-min))
@@ -1007,7 +991,9 @@ misspellings, but do not open the correction UI."
                                           :check t))
           (count (length overlays))
           (idx 0))
-     (unless only-check
+     (if only-check
+         (message "%d misspelled word%s in buffer `%s'"
+                  count (if (= count 1) "" "s") (buffer-name))
        (deactivate-mark)
        (push-mark)
        (while-let ((ov (nth idx overlays)))
@@ -1173,7 +1159,7 @@ symbols or elements of the form (not modes)."
                                   ('nil 0)
                                   ((pred symbolp) (and (derived-mode-p p) t))
                                   (`(not . ,m) (and (seq-some #'derived-mode-p m) 0)))))))
-    (jinx-mode 1)))
+    (jinx-mode)))
 
 (provide 'jinx)
 ;;; jinx.el ends here
